import time
import functools
import sys
from importlib import reload


def show_gpu():
    import torch
    if torch.cuda.is_available():
        print(f"There is/are {torch.cuda.device_count()} gpus.")
        for i in range(torch.cuda.device_count()):
            print(f"the model of card {i} is {torch.cuda.get_device_name(i)}")
        print("for more info, run nvidia-smi")
    else:
        print("no gpu available")


def hello_world():
    print("hello this is nlpbaselines!")


def timer(func):
    @functools.wraps(func)
    def time_closure(*args, **kwargs):
        start = time.perf_counter()
        result = func(*args, **kwargs)
        time_elapsed = time.perf_counter() - start
        print(f"Function: {func.__name__}, Time: {time_elapsed}")
        return result
    return time_closure


def reimport_all(package):
    reload(sys.modules[package])



# # 2.3667990922927857
# from svd2vec import svd2vec
# # import svd2vec
# import pickle
# import os
# import glob
# # print(svd2vec.__file__)
# import multiprocessing as mp
# import time

# start = time.time()
# # print(f"{mp.cpu_count()} cpus")

# # number_of_cores = mp.cpu_count()
# number_of_cores = 16
# # number_of_cores = 1
# fnlp_punc = list('''!()-[]{};:'"\,<>./?@#$%^&*_~«»“”''')
# # os.system(f"echo {number_of_cores} cpus allocated")

# fns = glob.glob(
#     "/Users/xiaoou/Documents/data/output_stanza/lemmas_article/*.pickle")

# os.system(f"echo {len(fns)} pickles")

# documents = []

# fns = fns[:1]

# for fn in fns:
#     # os.system(f'echo {fns} loaded')
#     with open(fn, 'rb') as f:
#         document = pickle.load(f)
#         # remove punctuation
#         for x in document:
#             documents.append([y
#                               for y in x if y not in fnlp_punc])

# del fns
# # del document

# from utils import show_gpuinfo

# show_gpuinfo()



from nlpbaselines import files


import re
s = "Example String\na test"

replaced = re.sub('a', 'aa', s)
print(replaced)

xx = "guru99,education is fun"
r1 = re.search(r"[\d]+", xx)
print(r1.group(0))



a = list(open("./filenames.txt","r"))
a = [x.strip() for x in a]
b = list(open("./filenames_more.txt","r"))
b = [x.strip() for x in b]
print(len(a),len(b))
not_done = [x for x in b if x not in a]
print(not_done)



from nlpbaselines import files

p = files.load_pickle("/Users/xiaoou/Documents/data/output_stanza/lemmas_article/frwac_articles_2270000_lemmas_article.pickle")
print(len(p))
print(p[0])

# files.load_pickle("tokens_sentences/frwac_articles_10000_tokens_sentences.pickle")


import re
from nlpbaselines import *

fns = ['1410000', '300000', '140000', '330000', '40000', '480000', '10000', '20000', '290000', '70000',
       '50000', '320000', '100000', '240000', '110000', '250000', '310000', '30000', '370000', '260000']


all_files = iter_documents(".", "pickle")
# print(list(all))
# print(len(list(all_files)))
# print(all_files)
to_del = []
# for xn in fns:
for y in all_files:
    # print(re.search(r"\d+", y).string)
    if re.search(r"\d+", y).group(0) in fns:
        to_del.append(y)
# print(to_del)
# print(len(to_del))
# print(to_del[0])
for f in to_del:
    os.remove(f)
# for r, d, files in os.walk("."):
#     print([file for file in filter(lambda file: file.endswith("."+"pickle"), files)])



from svd2vec import svd2vec
# import svd2vec
# print(svd2vec.__file__)
documents = ["this is a test right left".split(
)*30, "this is the second test left right".split()*30]
svd = svd2vec(documents, window=2, min_count=0, size=4, verbose=True)



from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()

setup_args = dict(
    name='nlpbaselines',
    version='0.0.21',
    description='Establish quick baselines for NLP tasks',
    long_description_content_type="text/markdown",
    long_description=README,
    include_package_data=True,
    license='Apache Licence 2.0',
    packages=find_packages(),
    author='Xiaoou WANG',
    author_email='xiaoouwangfrance@gmail.com',
    keywords=['text mining', 'npl', 'corpus',
              'french', 'bert', 'transformers'],
    url='https://github.com/xiaoouwang/nlpbaselines',
    download_url='https://pypi.org/project/nlpbaselines/',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

install_requires = [
    'numpy',
    'pandas',
    'transformers',
    'torch',
    'py7zr',
    # 'sentence_transformers',
    'sklearn',
    'tensorflow'
]


if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)
